scipy.interpolate.BivariateSpline
=================================

.. currentmodule:: scipy.interpolate

.. autoclass:: BivariateSpline

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         BivariateSpline.__call__
         BivariateSpline.ev
         BivariateSpline.get_coeffs
         BivariateSpline.get_knots
         BivariateSpline.get_residual
         BivariateSpline.integral



   

